==> qmmp-0.12.20.tar.bz2: qmmp-0.12.20/src/plugins/General/hal/translations/hal_plugin_id.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="id">
<context>
    <name>HalFactory</name>
    <message>
        <location filename="../halfactory.cpp" line="31"/>
        <source>HAL Plugin</source>
        <translation>Plugin HAL</translation>
    </message>
    <message>
        <location filename="../halfactory.cpp" line="51"/>
        <source>About HAL Plugin</source>
        <translation>Tentang Plugin HAL</translation>
    </message>
    <message>
        <location filename="../halfactory.cpp" line="52"/>
        <source>Qmmp HAL Plugin</source>
        <translation>Plugin HAL Qmmp</translation>
    </message>
    <message>
        <location filename="../halfactory.cpp" line="53"/>
        <source>This plugin provides removable devices detection using HAL</source>
        <translation>Plugin ini menyediakan deteksi perangkat dapat-dilepas menggunakan HAL</translation>
    </message>
    <message>
        <location filename="../halfactory.cpp" line="54"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>Ditulis oleh: Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
    </message>
    <message>
        <location filename="../halfactory.cpp" line="55"/>
        <source>Based on Solid (KDE hardware library)</source>
        <translation>Berdasarkan pada Solid (pustaka hardware KDE)</translation>
    </message>
</context>
<context>
    <name>HalPlugin</name>
    <message>
        <location filename="../halplugin.cpp" line="160"/>
        <source>Add CD &quot;%1&quot;</source>
        <translation>Tambah CD &quot;%1&quot;</translation>
    </message>
    <message>
        <location filename="../halplugin.cpp" line="166"/>
        <source>Add Volume &quot;%1&quot;</source>
        <translation>Tambah Volume %1&quot;</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="13"/>
        <source>HAL Plugin Settings</source>
        <translation>Setelan Plugin HAL</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="28"/>
        <source>CD Audio Detection</source>
        <translation>Deteksi Audio CD</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="37"/>
        <source>Add tracks to playlist automatically</source>
        <translation>Tambah track ke daftarmain secara otomatis</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="44"/>
        <source>Remove tracks from playlist automatically</source>
        <translation>Buang track dari daftarmain secara otomatis</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="54"/>
        <source>Removable Device Detection</source>
        <translation>Deteksi Perangkat Dapat-dilepas</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="63"/>
        <source>Add files to playlist automatically</source>
        <translation>Tambah file ke daftarmain secara otomatis</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="70"/>
        <source>Remove files from playlist automatically</source>
        <translation>Buang file dari daftarmain secara otomatis</translation>
    </message>
</context>
</TS>

==> qmmp_1.2.6.orig.tar.bz2: qmmp-1.2.6/src/plugins/General/hal/translations/hal_plugin_id.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="id">
<context>
    <name>HalFactory</name>
    <message>
        <location filename="../halfactory.cpp" line="31"/>
        <source>HAL Plugin</source>
        <translation>Plugin HAL</translation>
    </message>
    <message>
        <location filename="../halfactory.cpp" line="51"/>
        <source>About HAL Plugin</source>
        <translation>Tentang Plugin HAL</translation>
    </message>
    <message>
        <location filename="../halfactory.cpp" line="52"/>
        <source>Qmmp HAL Plugin</source>
        <translation>Plugin HAL Qmmp</translation>
    </message>
    <message>
        <location filename="../halfactory.cpp" line="53"/>
        <source>This plugin provides removable devices detection using HAL</source>
        <translation>Plugin ini menyediakan deteksi perangkat dapat-dilepas menggunakan HAL</translation>
    </message>
    <message>
        <location filename="../halfactory.cpp" line="54"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../halfactory.cpp" line="55"/>
        <source>Based on Solid (KDE hardware library)</source>
        <translation>Berdasarkan pada Solid (pustaka hardware KDE)</translation>
    </message>
</context>
<context>
    <name>HalPlugin</name>
    <message>
        <location filename="../halplugin.cpp" line="160"/>
        <source>Add CD &quot;%1&quot;</source>
        <translation>Tambah CD &quot;%1&quot;</translation>
    </message>
    <message>
        <location filename="../halplugin.cpp" line="166"/>
        <source>Add Volume &quot;%1&quot;</source>
        <translation>Tambah Volume %1&quot;</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="13"/>
        <source>HAL Plugin Settings</source>
        <translation>Setelan Plugin HAL</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="28"/>
        <source>CD Audio Detection</source>
        <translation>Deteksi Audio CD</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="37"/>
        <source>Add tracks to playlist automatically</source>
        <translation>Tambah track ke daftarmain secara otomatis</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="44"/>
        <source>Remove tracks from playlist automatically</source>
        <translation>Buang track dari daftarmain secara otomatis</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="54"/>
        <source>Removable Device Detection</source>
        <translation>Deteksi Perangkat Dapat-dilepas</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="63"/>
        <source>Add files to playlist automatically</source>
        <translation>Tambah file ke daftarmain secara otomatis</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="70"/>
        <source>Remove files from playlist automatically</source>
        <translation>Buang file dari daftarmain secara otomatis</translation>
    </message>
</context>
</TS>
